@@ -8,7 +8,7 @@ from sqlalchemy.types import (
     BigInteger as bigint,
     Text as text,
     Numeric as numeric,
-    LargeBinary as large_binary,
+    LargeBinary as largebinary,
 )
 
 from datetime import datetime, date, time
@@ -37,7 +37,7 @@ __all__ = [
     'bigint',
     'text',
     'numeric',
-    'large_binary',
+    'largebinary',
     'query',
     'View',
     'Enum',
